module Hermes
  module Api
    module Dmo
      class EntityReservationsController < Hermes::Api::Dmo::ApplicationController

        MUTATE_PARAMS = %i[
           name
           from
           to
           housing_offer_id
           entity_id
        ]

        VALID_OPERATORS = %w[
          $in
          $nin
          $ne
          $regex
        ]

        ACCEPTABLE_PARAMS = %w[
          name
          from
          to
          housing_offer_id
          entity_id
          is_active
        ]

        REGEX_PARAMS = %w[
          name
        ]
        
        def mutate_params
          MUTATE_PARAMS
        end 
        
        def index
          acceptable_params *ACCEPTABLE_PARAMS
          regex_params *REGEX_PARAMS
          valid_operators *VALID_OPERATORS
          
          paginate(
            index_aggregation,
            each_serializer: @serializer,
            **@options
          )
        end

        def destroy
          @instance = @model.find(params[:id])
          return render_json_error(:not_found, :instance_not_found) unless @instance
          return render(json: @instance.errors, status: :unprocessable_entity) unless @instance.destroy
  
          render(body: nil, status: :no_content)
        end
      end
    end
  end
end