# frozen_string_literal: true

# checker Api::Dmo::HermesController avant d'ajouter des méthodes
module Hermes
  module Api
    module Dmo
      class UntensedAreasController < Hermes::Api::Dmo::ApplicationController
        before_action :check_if_allowed
  
        VALID_OPERATORS = %w[
          $in
          $nin
          $ne
          $gt
          $gte
          $lt
          $lte
          $regex
        ]

        ACCEPTABLE_PARAMS = %w[
        ids
          insee_code
          department
        ]

        REGEX_PARAMS = %w[
           insee_code
          department
        ]

        MUTATE_PARAMS = %i[
          insee_code
          department
        ]
        
        def mutate_params
          MUTATE_PARAMS
        end 

        def index
          acceptable_params *ACCEPTABLE_PARAMS
          regex_params *REGEX_PARAMS
          valid_operators *VALID_OPERATORS
          super
        end
        
        
        def check_if_allowed
          return render_json_error(:unauthorized, :only_administrators_are_allowed_to_interact_with_untensed_areas) unless current_user_roles.include?('Administrator')
        end
      end
    end
  end
end
