# frozen_string_literal: true
# checker Api::Dmo::HermesController avant d'ajouter des méthodes
module Hermes
  module Api
    module Dmo
      class UserFiltersController < Hermes::Api::Dmo::ApplicationController

        VALID_OPERATORS = %w[
          $in
          $nin
          $ne
          $gt
          $gte
          $lt
          $lte
          $regex
        ].freeze

        ACCEPTABLE_PARAMS = %w[
          key
          user_id
        ].freeze

        REGEX_PARAMS = %w[
        ].freeze

        MUTATE_PARAMS = %i[
          key
          user_id
          value
        ].freeze
        
        def mutate_params
          MUTATE_PARAMS
        end 
        
        def index
          acceptable_params *ACCEPTABLE_PARAMS
          regex_params *REGEX_PARAMS
          valid_operators *VALID_OPERATORS
          
          paginate(
            index_aggregation.where(user_id: current_user.id),
            each_serializer: @serializer,
            **@options
          )
        end
          
        def show 
          return render_json_error(:not_found, :instance_not_found) unless @instance
          return render_json_error(:unauthorized, :cannot_see_this_user_filter) unless is_user_filter

          super
        end
        
        def create
          return render_json_error(:unprocessable_entity, :missing_params) unless mutate_valid_params[:user_id].present? && mutate_valid_params[:key].present?
          return render_json_error(:unauthorized, :cannot_create_filter_for_other_user) unless current_user.id.to_s == mutate_valid_params[:user_id]

          if already_one_filter = Hermes::UserFilter.find_by(user_id: mutate_valid_params[:user_id], key: mutate_valid_params[:key])
            @instance = already_one_filter
            return respond_with_errors(@instance) unless @instance.update(mutate_valid_params)

            return render(jsonapi: @instance, serializer: @serializer, status: :created)
          end 

          super
        end

        def destroy 
          return render_json_error(:not_found, :instance_not_found) unless @instance
          return render_json_error(:unauthorized, :cannot_delete_other_user_filter) unless is_user_filter
          return render(json: @instance.errors, status: :unprocessable_entity) unless @instance.destroy

          render(body: nil, status: :no_content)
        end 

        private 

        def is_user_filter
          @instance&.user_id == current_user.id
        end 

        def set_instance
          @instance = @model.find_by(id: params[:id]) if params[:id]
        end

      end
    end
  end
end
