# frozen_string_literal: true

# Handle orientation dependencies for a request
class HandleRequestOrientationMovementJob < ActiveJob::Base
 
  queue_as :rmvlow
  unique :until_executed

  def perform(request_id, request_orientation_changes)
    # @request_id: String => request target
    # @request_orientation_changes: |v Hash v|
    #   {
    #     priority_public: 1,
    #     single_parent: -1,
    #     ... ,
    #     entities: {
    #       id1: -1,
    #       id2: 1,
    #       ...
    #     }
    #   }

    # kill other pending jobs

    if request = Hermes::HousingRequest.find_by(id: request_id)
      offer_ids = Hermes::HousingOffer.where(eligibility_query.json_to_h).pluck(:id).map(&:to_s)
      if offer_ids.present?
        offer_ids.each do |offer_id|
          HandleOfferEligibleNbJob.perform_later(offer_id, request_orientation_changes)
        end
      end
    end
  end
end
