# frozen_string_literal: true

module Hermes
  class LogJob < ActiveJob::Base
    queue_as :x_hermes_log

    QUEUE_NAME = 'redis_hermes_logs_queue'
    QUEUE_MAX_SIZE = 100
    
    def perform
      bulk_write = []

      loop do
        break unless attributes_json = $redis.lpop(QUEUE_NAME)
        
        attributes = JSON.parse(attributes_json).symbolize_keys
        attributes[:created_at] = DateTime.parse(attributes[:created_at])
        attributes[:updated_at] = attributes[:created_at]
        attributes[:d] = attributes[:d]&.to_json


        bulk_write.push({ insert_one: attributes})
      end 

      Log.collection.bulk_write(bulk_write)
    end

    def self.add_to_queue(attributes, options = {})
      return unless attributes
      force_perform_now = options[:force_perform_now]

      attributes[:created_at] = attributes[:created_at]&.to_s || DateTime.current.to_s
      attributes[:level] = 'info' unless attributes[:level].present?
      attributes[:domain] = 'api' unless attributes[:domain].present?

      $redis.lpush(QUEUE_NAME, attributes.to_json)

      if queue_size >= queue_max_size
        force_perform_now ? perform_now : perform_later 
      end
    end

    def self.queue_size
      $redis.llen(QUEUE_NAME)
    end 

    def self.queue_max_size
      QUEUE_MAX_SIZE
    end 
  end
end
